FreeOnlyAllocator

Struct FreeOnlyAllocator 

pub struct FreeOnlyAllocator { /* private fields */ }

Implementations

Source

impl FreeOnlyAllocator

pub fn join(file: &File) -> Result<Self, Error>

Join an existing allocator in the provided file.

Note

Prefer Self::join_from_existing to re-use mmaps within the same process.

pub fn join_from_existing(existing: &Allocator) -> Self

Join an existing allocator using the same in-process mapping.

pub fn join_from_existing_free_only(existing: &FreeOnlyAllocator) -> Self

Join an existing free-only allocator using the same in-process mapping.

Source

impl FreeOnlyAllocator

pub unsafe fn free(&self, ptr: NonNull<u8>)

Free a block of memory previously allocated by this allocator.

Safety
  • The ptr must be a valid pointer to a block of memory allocated by this allocator.
  • The ptr must not have been freed before.
pub unsafe fn free_offset(&self, offset: usize)

Free a block of memory previously allocated by this allocator.

Safety
  • The offset must be a valid offset within the memory allocated by this allocator.
  • The offset must not have been freed before.
pub unsafe fn offset(&self, ptr: NonNull<u8>) -> usize

Find the offset given a pointer.

Safety
  • The ptr must be a valid pointer in the allocator’s address space.
pub unsafe fn ptr_from_offset(&self, offset: usize) -> NonNull<u8>

Return a ptr given a shareable offset - calculated by offset.

Safety
  • Caller must ensure the offset is valid for this allocator.