RemoteFreeBatch

Struct RemoteFreeBatch 

pub struct RemoteFreeBatch<'a> { /* private fields */ }
Collects frees and publishes remote frees in batches grouped by owning worker.

Frees owned by the worker represented by the Allocator handle that created the batch are reclaimed immediately. All other frees are linked into intrusive chains and published when Self::flush is called or the batch is dropped.

Implementations

Source

impl<'a> RemoteFreeBatch<'a>

pub unsafe fn free(&mut self, ptr: NonNull<u8>)

Free a block of memory from this allocator region.

Locally owned allocations are reclaimed immediately. Remote frees remain private to this batch until it is flushed or dropped.

Safety
  • ptr must point to a valid allocation in this allocator region.
  • The ptr must not have been freed before or added to another free batch.
pub unsafe fn free_offset(&mut self, offset: usize)

Free a block of memory from this allocator region.

Locally owned allocations are reclaimed immediately. Remote frees remain private to this batch until it is flushed or dropped.

Safety
  • offset must identify a valid allocation in this allocator region.
  • The offset must not have been freed before or added to another free batch.
pub fn flush(&mut self)

Publish all remote frees currently held by this batch.

The batch may be reused after flushing. Capacity allocated for destination workers is retained.