pub struct Allocator { /* private fields */ }Implementations
Sourceimpl Allocator
impl Allocator
Sourceimpl Allocator
impl Allocator
Sourcepub unsafe fn free(&self, ptr: NonNull<u8>)
pub unsafe fn free(&self, ptr: NonNull<u8>)
Free a block of memory previously allocated by this allocator.
Safety
- The
ptrmust be a valid pointer to a block of memory allocated by this allocator. - The
ptrmust not have been freed before.
Sourcepub unsafe fn free_offset(&self, offset: usize)
pub unsafe fn free_offset(&self, offset: usize)
Free a block of memory previously allocated by this allocator.
Safety
- The
offsetmust be a valid offset within the memory allocated by this allocator. - The
offsetmust not have been freed before.
Sourceimpl Allocator
impl Allocator
Sourcepub fn clean_remote_free_lists(&self)
pub fn clean_remote_free_lists(&self)
Frees all items in remote free lists.