pub struct RemoteFreeBatch<'a> { /* private fields */ }Expand description
Collects frees and publishes remote frees in batches grouped by owning worker.
Frees owned by the worker represented by the Allocator handle that created
the batch are reclaimed immediately. All other frees are linked into intrusive
chains and published when Self::flush is called or the batch is dropped.
Implementations
Sourceimpl<'a> RemoteFreeBatch<'a>
impl<'a> RemoteFreeBatch<'a>
Sourcepub unsafe fn free(&mut self, ptr: NonNull<u8>)
pub unsafe fn free(&mut self, ptr: NonNull<u8>)
Free a block of memory from this allocator region.
Locally owned allocations are reclaimed immediately. Remote frees remain private to this batch until it is flushed or dropped.
Safety
ptrmust point to a valid allocation in this allocator region.- The
ptrmust not have been freed before or added to another free batch.
Sourcepub unsafe fn free_offset(&mut self, offset: usize)
pub unsafe fn free_offset(&mut self, offset: usize)
Free a block of memory from this allocator region.
Locally owned allocations are reclaimed immediately. Remote frees remain private to this batch until it is flushed or dropped.
Safety
offsetmust identify a valid allocation in this allocator region.- The
offsetmust not have been freed before or added to another free batch.